#!/bin/csh -f
#
# Shell script to process Salton Sea data
#
if( $#argv == 0 ) then
   grep '^## ' $0 | awk '{print substr($0,3)}'
# Here are the options
## Usage: Salton.cmd <options>
## where the following options are avaiable
#3  -o <offset>  Week offset from current week.
##  -w <week>    Week to be processed.
##  -globk_only  Run globk only (needed if gamit runs are re-done mamually
##  -d yr day    where yr and day are to processed e.g. 1997 153
##  -m           mail sinex files to  
##
## Script run from <proc_dir>/control directory
##
   exit

endif
setenv INSTITUTE MIT
set glbk_only = "N"
set mailto = "NONE"

foreach a ($argv)
switch($a)
    case -o:
      set off = $argv[2]
      set week = `doy | tail -2 | head -1 | awk -v off=$off '{print $3-off}'`
      breaksw
    case -w:
      set week = $argv[2]
      breaksw
    case -g*:
      set glbk_only = "Y"
      breaksw
    case -m*:
      set mailto = $argv[2]
      breaksw
    endsw
    shift
end
#
echo "Salton: Week $week GlobkOnly $glbk_only Mail $mailto"

# Move up to the top level directory
cd ..
#
set logf = control/Salt${week}.log
if( ! -e $logf ) then
    date >! $logf
else
    echo "--------------------------------------------" >> $logf
    date >> $logf
endif

### If we are running gamit loop over the days of the week

if( $glbk_only == "N" ) then
   set d = -1
   while ( $d < 6 )
      @ d ++
      set yr = `doy ${week}W $d | head -1 | awk '{print substr($2,1,4)}'`
      set dy = `doy ${week}W $d | head -1 | awk '{printf("%3.3d", $6)}'`
      sh_gamit -d $yr $dy  -orbit IGSF -yrext -netext a -expt salt -sessinfo 30 720 00 00        >>& $logf
      sh_gamit -d $yr $dy  -orbit IGSF -yrext -netext b -expt salt -sessinfo 30 720 06 00 -noftp >>& $logf
      sh_gamit -d $yr $dy  -orbit IGSF -yrext -netext c -expt salt -sessinfo 30 720 12 00 -noftp >>& $logf
      sh_gamit -d $yr $dy  -orbit IGSF -yrext -netext d -expt salt -sessinfo 30 720 18 00 -noftp >>& $logf
#
#     Run htgolb
      htoglb glbf glbf/svt ${yr}_${dy}[a-d]/hsalt* >> $logf
    end
endif
#
# Now do globk runs
#
if( $glbk_only == "N" || $glbk_only == "Y" ) then 
   cd gsoln 
   if( ! -e ../sinex ) mkdir ../sinex

   set logf = ../control/Salt${week}.log
   set d = -1
   while ( $d < 6 )
      @ d ++
      set ymd =  `doy ${week}W $d | head -1 | awk '{print substr($2,3,2)substr($2,6,2)substr($2,9,2)}'` 
      ls ../glbf/h${ymd}????_salt.glx >! salt${week}${d}.gdl
      \rm  salt${week}${d}_rep.org >&! /dev/null
      glred 6 salt${week}${d}_rep.prt salt${week}${d}_rep.log  salt${week}${d}.gdl  globk_rep.cmd SAVE >> $logf
      tssum ts_6hr/ slt.final_frame -n salt${week}${d}_rep.org
#
#     Now make the 24-hour session
      \rm salt${week}${d}_day.org >&! /dev/null
      globk 6 salt${week}${d}_day.prt salt${week}${d}_day.log  salt${week}${d}.gdl  globk_rep.cmd DAY >> $logf
      tssum ts_6hr/ slt.daily_frame -n salt${week}${d}_day.org
      glbtosnx ../sinex '' salt${week}${d}.glb.CON salt${ymd}D.snx >> $logf

#
#     Now make the sinex files
      set fs = `ls L${ymd}????_salt.glb.CON`
      foreach f ( `echo $fs`)
         set base = `echo $f | awk '{print substr($1,2,8)}'`
         glbtosnx ../sinex '' $f slt${base}.snx >> $logf
      end
      \rm L${ymd}????_salt.glb* salt${week}${d}.glb*
   end

#  Now do the weekly solution
   cat salt${week}?.gdl >! salt${week}.gdl
   \rm salt${week}_week.org >&! /dev/null
   globk 6 salt${week}_week.prt salt${week}_week.log  salt${week}.gdl  globk_rep.cmd WEEK >> $logf
   tssum ts_6hr/ slt.weeka_frame -n salt${week}_week.org
   glbtosnx ../sinex '' salt${week}.glb.CON salt${week}W.snx >> $logf
   \rm salt${week}.glb*
#
#  Now tar and gzip the week
   cd ../sinex
   set d = -1
   set list = ''
   while ( $d < 6 )
      @ d ++
      set list = ( "$list" `doy ${week}W $d | head -1 | awk '{print "slt"substr($2,3,2)substr($2,6,2)substr($2,9,2)"??.snx"}'` )
      set list = ( "$list" `doy ${week}W $d | head -1 | awk '{print "salt"substr($2,3,2)substr($2,6,2)substr($2,9,2)"D.snx"}'` )
   end
   set list = ( "$list" salt${week}W.snx) 
   tar cvf slt${week}.tar $list >>  $logf
   gzip -vf slt${week}.tar >>&  $logf
   \mv slt${week}.tar.gz tars

#   if( $mailto != "NONE" ) then
endif


        
    




 


